<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
    xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl cs">

	<!--インベントリ情報をエクスポート-->
	<xsl:include href="CSV_Inventory.xslt" />

	<xsl:output method="text" media-type="text/plain" encoding="UTF-8" indent="no"/>

	<xsl:param name="Progress">
		<xsl:choose>
			<xsl:when test="/Data/Progress">
				<xsl:value-of select="number(/Data/Progress)"/>
			</xsl:when>
			<xsl:otherwise>-1</xsl:otherwise>
		</xsl:choose>
	</xsl:param>

	<xsl:param name="Done" select="/Data/Done"/>

	<xsl:template match="/">
		<xsl:call-template name="setting"/>
		<xsl:for-each select="/Data/Values/Value">
			<xsl:text>"</xsl:text>
			<xsl:choose>
				<xsl:when test="@Get = 'true'">
					<xsl:text/>
				</xsl:when>
				<xsl:when test="(position() - 1 &lt;= $Progress) or $Done = 'Done'">
					<xsl:text>[○]</xsl:text>
				</xsl:when>
				<xsl:when test="(position() - 2 = $Progress) and $Progress != -1">
					<xsl:text>[×]</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>[-]</xsl:text>
				</xsl:otherwise>
			</xsl:choose>

			<xsl:variable name="Value">
				<xsl:choose>
					<xsl:when test="@Get = 'true'">
						<xsl:value-of select="text()"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="Value">
							<xsl:value-of select="concat(@Name,': ', text())"/>
							<xsl:if test="position() != last()">
								<xsl:text>, </xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>

			<xsl:choose>
				<xsl:when test="contains( $Value, '&quot;' )">
					<xsl:call-template name="escape_quotes">
						<xsl:with-param name="string" select="$Value" />
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Value"/>
				</xsl:otherwise>
			</xsl:choose>

			<xsl:text>",</xsl:text>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="escape_quotes">
		<xsl:param name="string" />
		<xsl:value-of select="substring-before( $string, '&quot;' )" />
		<xsl:text>""</xsl:text>
		<xsl:variable name="substring_after_first_quote" select="substring-after( $string, '&quot;' )" />
		<xsl:choose>
			<xsl:when test="not( contains( $substring_after_first_quote, '&quot;' ) )">
				<xsl:value-of select="$substring_after_first_quote" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="escape_quotes">
					<xsl:with-param name="string" select="$substring_after_first_quote"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>